@@ -1,7 +1,5 @@
 from django.db.models.loading import get_models
-#from django.conf import settings
-
-from dse import *
+from dse import ModelDelayedExecutor
 
 # credit: http://greengiraffe.posterous.com/singleton-pattern-in-python
 def singleton(cls, model):
